summaryrefslogtreecommitdiff
path: root/src/parser/input.h
diff options
context:
space:
mode:
authorAndrew Reynolds <andrew.j.reynolds@gmail.com>2020-02-24 15:37:48 -0600
committerGitHub <noreply@github.com>2020-02-24 15:37:48 -0600
commit9fbe415992986d33d09b3b9e5049ebc22d20790a (patch)
tree986c6a139e2de4d324aa470b029af88cbcda301f /src/parser/input.h
parentc4f2ca4c1931f91a9647f0daa032ee9417f1b382 (diff)
Convert parser input interface to api::Term (#3809)
Diffstat (limited to 'src/parser/input.h')
-rw-r--r--src/parser/input.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/parser/input.h b/src/parser/input.h
index 5627dc15e..f63a55707 100644
--- a/src/parser/input.h
+++ b/src/parser/input.h
@@ -24,9 +24,10 @@
#include <string>
#include <vector>
-#include "options/language.h"
+#include "api/cvc4cpp.h"
#include "expr/expr.h"
#include "expr/expr_manager.h"
+#include "options/language.h"
#include "parser/parser_exception.h"
namespace CVC4 {
@@ -164,11 +165,11 @@ class CVC4_PUBLIC Input {
/** Parse an expression from the input by invoking the
* implementation-specific parsing method. Returns a null
* <code>Expr</code> if there is no expression there to parse.
*
* @throws ParserException if an error is encountered during parsing.
*/
- virtual Expr parseExpr() = 0;
+ virtual api::Term parseExpr() = 0;
/** Set the Parser object for this input. */
virtual void setParser(Parser& parser) = 0;
generated by cgit on debian on lair
@@ -164,11 +165,11 @@ class CVC4_PUBLIC Input {
/** Parse an expression from the input by invoking the
* implementation-specific parsing method. Returns a null
- * <code>Expr</code> if there is no expression there to parse.
+ * <code>api::Term</code> if there is no expression there to parse.
*
* @throws ParserException if an error is encountered during parsing.
contact matthew@masot.net with questions or feedback